"""Predicates for use in Controller & Action Protector decorators.
"""

from repoze.what.predicates import Predicate

import sloecode.lib.security as security

class has_site_role(Predicate):
    """Checks whether the logged in user has the desired site role.
    """
    message = 'You must be a "%(role_wanted)s" to access this resource.'

    def __init__(self, role, **kwargs):
        self.role_wanted = role
        super(has_site_role, self).__init__(**kwargs)

    def evaluate(self, environ, credentials):
        try:
            if not security.has_site_role(self.role_wanted):
                self.unmet()
        except KeyError:
            self.unmet()

class owns_page(Predicate):
    """Checks whether the logged in user owns the resource.
    """
    message = 'You do not own this resource.'

    def __init__(self, **kwargs):
        super(owns_page, self).__init__(**kwargs)

    def evaluate(self, environ, credentials):
        try:
            args = self.parse_variables(environ)
            named_args = args['named_args']
            person_name = named_args['person_name']
            if person_name != credentials['repoze.what.userid']:
                self.unmet()
        except KeyError:
            self.unmet()

class access_own(Predicate):
    """Checks that this users is attempting to modify their own details
    """

    message = "You don't have the permission to modify this User"

    def evaluate(self, environ, credentials):
        try:
            user = environ['repoze.who.identity'].get('user')
            args = self.parse_variables(environ)
            named_args = args['named_args']
            user_id = int(named_args['id'])

            if user.id != user_id:
                self.unmet()
        except KeyError:
            self.unmet()

class is_project_member(Predicate):
    """Checks whether the logged in user is a member of the project resource
    being requested.
    """

    message = "You must be a member of a project in order to view it's page."

    def evaluate(self, environ, credentials):
        try:
            user = environ['repoze.who.identity'].get('user')
            args = self.parse_variables(environ)
            named_args = args['named_args']
            project_name = named_args['project_name']
            for membership in user.projects:
                if membership.project.name == project_name:
                    return
            self.unmet()
        except KeyError:
            self.unmet()
