# This is a Twisted application config file.  To run, use:
#     twistd -noy bzrssh.tac
# or similar.  Refer to the twistd(1) man page for details.

from twisted.application import service

from sloecode.lib.readconf import get_conf
from sloecode.sshserver.daemon import make_portal
from sloecode.sshserver.service import SSHService

# TODO: It would be nice to separate smartserver config from other default
# config. In theory, adding 'use="smartserver"' to the call below will tell
# it to look at the 'app:smartserver' section. Problem is that paste then 
# expects to load and serve a WSGI app, which the smartserver isn't. For now,
# this is a nasty hack - all the smartserver config is in the [DEFAULT]
# section.
config = get_conf('smartserver')

# Construct an Application that has the codehosting SSH server.
application = service.Application('smartserver')
svc = SSHService(
    portal=make_portal(),
    private_key_path=config['private_key_file'],
    public_key_path=config['public_key_file'],
    main_log=config['log_name'],
    access_log=config['access_log_name'],
    strport=config['ssh_port'],
    idle_timeout=int(config['idle_timeout']),
    banner=config['banner'])
svc.setServiceParent(application)


class ReadyService(service.Service):
    """Service that logs a 'ready!' message once the reactor has started."""

    def startService(self):
        from twisted.internet import reactor
        #reactor.addSystemEventTrigger(
        #    'after', 'startup', log.msg, 'Smart server ready!')
        service.Service.startService(self)


# Service that announces when the daemon is ready
# ReadyService().setServiceParent(application)
